@@ -9,9 +9,9 @@ var searchData=
   ['bindings_6',['Modifiers key bindings',['../keymap-text-format-v1-v2.html#modifiers-bindings',1,'']]],
   ['block_7',['The “xkb_keymap” block',['../keymap-text-format-v1-v2.html#the-xkb_keymap-block',1,'']]],
   ['break_20a_20latch_20before_20triggering_20another_20latch_20or_20lock_8',['How do I break a latch before triggering another latch or lock?',['../faq.html#how-do-i-break-a-latch-before-triggering-another-latch-or-lock',1,'']]],
-  ['breaking_20changes_9',['Breaking changes',['../release-notes.html#breaking-changes',1,'Breaking changes'],['../release-notes.html#breaking-changes-1',1,'Breaking changes'],['../release-notes.html#breaking-changes-2',1,'Breaking changes'],['../release-notes.html#breaking-changes-3',1,'Breaking changes'],['../release-notes.html#breaking-changes-4',1,'Breaking changes'],['../release-notes.html#breaking-changes-5',1,'Breaking changes'],['../release-notes.html#breaking-changes-6',1,'Breaking changes'],['../release-notes.html#breaking-changes-7',1,'Breaking changes'],['../release-notes.html#breaking-changes-8',1,'Breaking changes'],['../release-notes.html#breaking-changes-9',1,'Breaking changes'],['../release-notes.html#breaking-changes-10',1,'Breaking changes']]],
+  ['breaking_20changes_9',['Breaking changes',['../release-notes.html#breaking-changes',1,'Breaking changes'],['../release-notes.html#breaking-changes-1',1,'Breaking changes'],['../release-notes.html#breaking-changes-2',1,'Breaking changes'],['../release-notes.html#breaking-changes-3',1,'Breaking changes'],['../release-notes.html#breaking-changes-4',1,'Breaking changes'],['../release-notes.html#breaking-changes-5',1,'Breaking changes'],['../release-notes.html#breaking-changes-6',1,'Breaking changes'],['../release-notes.html#breaking-changes-7',1,'Breaking changes'],['../release-notes.html#breaking-changes-8',1,'Breaking changes'],['../release-notes.html#breaking-changes-9',1,'Breaking changes'],['../release-notes.html#breaking-changes-10',1,'Breaking changes'],['../release-notes.html#breaking-changes-11',1,'Breaking changes']]],
   ['buffer_20size_10',['XKB-134 – Insufficient buffer size',['../error-index.html#XKB-134',1,'']]],
-  ['build_20system_11',['Build system',['../release-notes.html#build-system',1,'Build system'],['../release-notes.html#build-system-1',1,'Build system'],['../release-notes.html#build-system-2',1,'Build system'],['../release-notes.html#build-system-3',1,'Build system'],['../release-notes.html#build-system-4',1,'Build system'],['../release-notes.html#build-system-5',1,'Build system'],['../release-notes.html#build-system-6',1,'Build system']]],
+  ['build_20system_11',['Build system',['../release-notes.html#build-system',1,'Build system'],['../release-notes.html#build-system-1',1,'Build system'],['../release-notes.html#build-system-2',1,'Build system'],['../release-notes.html#build-system-3',1,'Build system'],['../release-notes.html#build-system-4',1,'Build system'],['../release-notes.html#build-system-5',1,'Build system'],['../release-notes.html#build-system-6',1,'Build system'],['../release-notes.html#build-system-7',1,'Build system']]],
   ['building_12',['Building',['../index.html#building',1,'']]],
   ['built_20in_20settings_13',['Built-in settings',['../keymap-text-format-v1-v2.html#built-in-settings',1,'']]],
   ['by_20step_14',['Example: define and use a modifier, step by step',['../keymap-text-format-v1-v2.html#example-define-and-use-a-modifier-step-by-step',1,'']]]
